pub struct ChromiumRuntimeShutdownStateReader { /* private fields */ }Expand description
Cloneable reader for observing runtime shutdown state from other threads.
Implementations
Sourceimpl ChromiumRuntimeShutdownStateReader
impl ChromiumRuntimeShutdownStateReader
Sourcepub fn shutdown_state(&self) -> ChromiumRuntimeShutdownState
pub fn shutdown_state(&self) -> ChromiumRuntimeShutdownState
Returns the latest shutdown state recorded by the runtime controller.