Module process

Module process 

Structs

ChromiumProcess
A handle to the running Chromium process.
ChromiumProcessOptions
Options for launching the Chromium process.
StartChromiumOptions
Combined options for launching Chromium and connecting the backend.

Enums

RuntimeSelection
Runtime selection for Chromium-backed startup.

Functions

resolve_chromium_executable
Resolves Chromium executable path for CBF applications.
start_chromium
Launches the Chromium process and connects to it via an inherited Mojo endpoint.